@@ -1,15 +1,7 @@
 /*
- * Copyright (C) 2010,2011,2012 Rolf Eike Beer <kde@opensource.sf-tec.de>
- */
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2010, 2011, 2012 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kgpgdecrypt.h"
 
@@ -54,11 +46,7 @@ KGpgDecrypt::command() const
 	if (!m_outFilename.isEmpty())
 		ret << QLatin1String("-o") << m_outFilename;
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-	ret << KGpgSettings::customDecrypt().simplified().split(QLatin1Char(' '), QString::SkipEmptyParts);
-#else
 	ret << KGpgSettings::customDecrypt().simplified().split(QLatin1Char(' '), Qt::SkipEmptyParts);
-#endif
 
 	return ret;
 }
@@ -123,12 +111,12 @@ KGpgDecrypt::nextLine(const QString& line)
 		decryptSuccess = true;
 	} else if (!inputFiles.isEmpty()) {
 		if (line == QLatin1String("[GNUPG:] BEGIN_DECRYPTION")) {
-			emit statusMessage(i18nc("Status message 'Decrypting <filename>' (operation starts)", "Decrypting %1", inputFiles.at(m_fileIndex).fileName()));
-			emit infoProgress(2 * m_fileIndex + 1, inputFiles.count() * 2);
+			Q_EMIT statusMessage(i18nc("Status message 'Decrypting <filename>' (operation starts)", "Decrypting %1", inputFiles.at(m_fileIndex).fileName()));
+			Q_EMIT infoProgress(2 * m_fileIndex + 1, inputFiles.count() * 2);
 		} else if (line == QLatin1String("[GNUPG:] END_DECRYPTION")) {
-			emit statusMessage(i18nc("Status message 'Decrypted <filename>' (operation was completed)", "Decrypted %1", inputFiles.at(m_fileIndex).fileName()));
+			Q_EMIT statusMessage(i18nc("Status message 'Decrypted <filename>' (operation was completed)", "Decrypted %1", inputFiles.at(m_fileIndex).fileName()));
 			m_fileIndex++;
-			emit infoProgress(2 * m_fileIndex, inputFiles.count() * 2);
+			Q_EMIT infoProgress(2 * m_fileIndex, inputFiles.count() * 2);
 		}
 	} else {
 		if (line.startsWith(QLatin1String("[GNUPG:] PLAINTEXT_LENGTH "))) {
